@@ -22,21 +22,27 @@
 #include "dm_connection.h"
 
 #include <mir/default_server_configuration.h>
+#include <mir/shell/application_session.h>
 
 class Configuration;
 
 class SystemCompositor : public DMMessageHandler
 {
 public:
-    void run(int argc, char const** argv);
+    void run(int argc, char **argv);
+    void pause();
+    void resume();
 
 private:
     std::shared_ptr<mir::DefaultServerConfiguration> config;
     boost::asio::io_service io_service;
     std::shared_ptr<DMConnection> dm_connection;
+    std::shared_ptr<mir::shell::ApplicationSession> active_session;
 
-    virtual void set_active_session(std::string client_name);
+    void set_active_session(std::string client_name);
+    void set_next_session(std::string client_name);
     void main();
+    void qt_main(int argc, char **argv);
 };
 
 #endif /* SYSTEM_COMPOSITOR_H_ */
